@@ -28,3 +28,8 @@ def configure_views(app):
   app.add_url_rule('/vendors/<vendor_name>', 'vendor', views.vendor)
   app.add_url_rule('/categories/<category_name>', 'category', views.category)
   app.add_url_rule('/assets/<path:asset_name>', 'asset', views.asset)
+  app.add_url_rule('/cart', 'cart', views.cart,
+                   methods=('GET', 'POST'))
+  app.add_url_rule('/cart/add', 'cart_add', views.cart_add,
+                   methods=('GET','POST'))
+  app.add_url_rule('/cart/change', 'cart_change', views.cart_change)
