@@ -19,14 +19,13 @@ app = create_app()
 
 
 def main():
-  manager = Manager(app)
+  manager = Manager(app, with_default_commands=False)
   manager.add_command('runserver', BoutiqueServer())
   manager.add_command('login', Login())
   manager.add_command('whoami', Whoami())
   manager.add_command('list', List())
   manager.add_command('create', Create())
   manager.add_command('delete', Delete())
-  manager.add_command('deploy', Deploy())
 
   try:
     manager.run()
