@@ -21,7 +21,7 @@ class ObjectProperty(BaseProperty):
     self._prop_cls = cls
 
   def get_value(self, obj):
-    field_name = self._model_field_name if self._model_field_name is not None else self.name
+    field_name = self._model_field_name or self.name
     prop = getattr(obj._obj_data, field_name)
 
     if isinstance(property, types.MethodType):
@@ -46,4 +46,7 @@ class ObjectCollectionProperty(ObjectProperty):
       items = self._items_loader(obj._obj_data.id, obj._all_data)
     else:
       items = super(ObjectCollectionProperty, self).get_value(obj)
-    return ObjectCollection(cls=self._obj_class, items=items, key=self._key_name, all_data=obj._all_data)
+    return ObjectCollection(cls=self._obj_class,
+                            items=items,
+                            key=self._key_name,
+                            all_data=obj._all_data)
