@@ -1,10 +1,7 @@
 from .base.obj import BaseObject
-from .base.fields import ObjectProperty
-from .base.fields import ObjectCollectionProperty
-
-from .product import Product
-from .product import Vendor
-from .product import Category
+from .base.fields import ObjectProperty, ObjectCollectionProperty
+from .product import Product, Vendor, Category
+from .linklist import LinkList
 
 
 class Site(BaseObject):
@@ -24,6 +21,9 @@ class Site(BaseObject):
   categories = ObjectCollectionProperty(
       cls=Category,
       loader=lambda id_, d: d.categories)
+  linklists = ObjectCollectionProperty(
+      cls=LinkList,
+      loader=lambda id_, d: d.linklists)
 
   currency = ObjectProperty()
   unit_system = ObjectProperty()
